import re
import threading
from datetime import datetime
from inspect import getframeinfo, stack

from .util import post_db


def _log(
    traceback,
    service_name,
    severity_level,
    message,
    message_body=None,
    error=None,
    post=False,
):
    file = re.split(r"[ /\\]", str(traceback.filename))[-1]
    line_number = traceback.lineno
    thread = threading.get_ident()

    date_time = str(datetime.now()).replace("T", " ")

    print(
        f"\033[91m{severity_level}:{date_time} | {thread} | {service_name} | {file} - {line_number} | {message}"
    )

    if post:
        # data = {
        #     "service": service_name,
        #     "message": message,
        #     "security_level": security_level,
        #     "date": date_time,
        #     "location": f"{file} - {line_number}",
        # }
        #
        # if message_body:
        #     data["message_body"] = message_body
        #
        # if error:
        #     data["error"] = error

        post_db(
            table="service_logging",
            service=service_name,
            message=message,
            severity_level=severity_level,
            location=f"{file} - {line_number}",
            message_body=message_body,
            traceback=error,
        )


class AtlasLogger:
    def __init__(self, service_name):
        self.name = service_name

    def info(self, message, message_body=None):
        traceback = getframeinfo(stack()[1][0])
        _log(
            traceback=traceback,
            service_name=self.name,
            severity_level="INFO",
            message=message,
            message_body=message_body,
            post=True,
        )

    def warning(self, message, message_body=None):
        traceback = getframeinfo(stack()[1][0])
        _log(
            traceback=traceback,
            service_name=self.name,
            severity_level="WARNING",
            message=message,
            message_body=message_body,
            post=True,
        )

    def debug(self, message, message_body=None):
        traceback = getframeinfo(stack()[1][0])
        _log(
            traceback=traceback,
            service_name=self.name,
            severity_level="DEBUG",
            message=message,
            message_body=message_body,
            post=False,
        )

    def error(self, message, message_body=None, error=None):
        traceback = getframeinfo(stack()[1][0])
        _log(
            traceback=traceback,
            service_name=self.name,
            severity_level="ERROR",
            message=message,
            message_body=message_body,
            error=error,
            post=True,
        )

    def critical(self, message, message_body, error=None):
        traceback = getframeinfo(stack()[1][0])
        _log(
            traceback=traceback,
            service_name=self.name,
            severity_level="CRITICAL",
            message=message,
            message_body=message_body,
            error=error,
            post=True,
        )
